@@ -1,9 +1,5 @@
 angular.module('directives', [])
 
-.directive('code', function() {
-  return { restrict:'E', terminal: true };
-})
-
 /**
  * backToTop Directive
  * @param  {Function} $anchorScroll
@@ -25,7 +21,7 @@ angular.module('directives', [])
     restrict: 'E',
     terminal: true,
     compile: function(element) {
-      var linenums = element.hasClass('linenum') || element.parent()[0].nodeName === 'PRE';
+      var linenums = element.hasClass('linenum');// || element.parent()[0].nodeName === 'PRE';
       var match = /lang-(\S)+/.exec(element.className);
       var lang = match && match[1];
       var html = element.html();
