@@ -1,18 +1,27 @@
+"use strict";
+
 var gulp = require('gulp');
+var log = require('gulp-util').log;
 var concat = require('gulp-concat');
 var jshint = require('gulp-jshint');
 var bower = require('bower');
-var dgeni = require('dgeni');
+var Dgeni = require('dgeni');
 var merge = require('event-stream').merge;
 var path = require('canonical-path');
-
+var foreach = require('gulp-foreach');
+var uglify = require('gulp-uglify');
+var sourcemaps = require('gulp-sourcemaps');
+var rename = require('gulp-rename');
 
 // We indicate to gulp that tasks are async by returning the stream.
 // Gulp can then wait for the stream to close before starting dependent tasks.
 // See clean and bower for async tasks, and see assets and doc-gen for dependent tasks below
 
 var outputFolder = '../build/docs';
-var bowerFolder = '../bower_components';
+var bowerFolder = 'bower_components';
+
+var src = 'app/src/**/*.js';
+var assets = 'app/assets/**/*';
 
 
 var copyComponent = function(component, pattern, sourceFolder, packageFile) {
@@ -26,18 +35,48 @@ var copyComponent = function(component, pattern, sourceFolder, packageFile) {
 };
 
 gulp.task('bower', function() {
-  return bower.commands.install();
+  var bowerTask = bower.commands.install();
+  bowerTask.on('log', function (result) {
+    log('bower:', result.id, result.data.endpoint.name);
+  });
+  bowerTask.on('error', function(error) {
+    log(error);
+  });
+  return bowerTask;
 });
 
 gulp.task('build-app', function() {
-  gulp.src('app/src/**/*.js')
-    .pipe(concat('docs.js'))
-    .pipe(gulp.dest(outputFolder + '/js/'));
+  var file = 'docs.js';
+  var minFile = 'docs.min.js';
+  var folder = outputFolder + '/js/';
+
+  return gulp.src(src)
+    .pipe(sourcemaps.init())
+    .pipe(concat(file))
+    .pipe(gulp.dest(folder))
+    .pipe(rename(minFile))
+    .pipe(uglify())
+    .pipe(sourcemaps.write('.'))
+    .pipe(gulp.dest(folder));
 });
 
 gulp.task('assets', ['bower'], function() {
+  var JS_EXT = /\.js$/;
   return merge(
-    gulp.src(['app/assets/**/*']).pipe(gulp.dest(outputFolder)),
+    gulp.src([assets])
+      .pipe(gulp.dest(outputFolder)),
+    gulp.src([assets])
+      .pipe(foreach(function(stream, file) {
+        if (JS_EXT.test(file.relative)) {
+          var minFile = file.relative.replace(JS_EXT, '.min.js');
+          return stream
+            .pipe(sourcemaps.init())
+            .pipe(concat(minFile))
+            .pipe(uglify())
+            .pipe(sourcemaps.write('.'))
+            .pipe(gulp.dest(outputFolder));
+        }
+      })),
     copyComponent('bootstrap', '/dist/**/*'),
     copyComponent('open-sans-fontface'),
     copyComponent('lunr.js','/*.js'),
@@ -48,12 +87,11 @@ gulp.task('assets', ['bower'], function() {
 });
 
 
-gulp.task('doc-gen', function() {
-  var generateDocs = dgeni.generator('docs.config.js');
-  return generateDocs()
-    .catch(function(error) {
-      process.exit(1);
-    });
+gulp.task('doc-gen', ['bower'], function() {
+  var dgeni = new Dgeni([require('./config')]);
+  return dgeni.generate().catch(function(error) {
+    process.exit(1);
+  });
 });
 
 // JSHint the example and protractor test files
@@ -68,3 +106,6 @@ gulp.task('jshint', ['doc-gen'], function() {
 // The default task that will be run if no task is supplied
 gulp.task('default', ['assets', 'doc-gen', 'build-app', 'jshint']);
 
+gulp.task('watch', function() {
+  gulp.watch([src, assets], ['assets', 'build-app']);
+});
