@@ -2,4 +2,5 @@
 
 set -e
 PARENT_DIR="$(dirname "$0")"
-jasmine-node "$PARENT_DIR"/spec/
+
+../node_modules/.bin/jasmine-node "$PARENT_DIR"/spec/
