@@ -22,7 +22,12 @@ function readSymbols() {
     .then(function(content) {
       var currencySymbols = closureI18nExtractor.extractCurrencySymbols(content);
       return qfs.read(__dirname + '/../closure/numberSymbols.js', 'b').then(function(content) {
-          closureI18nExtractor.extractNumberSymbols(content, localeInfo, currencySymbols);
+          var numberSymbols = content;
+          return qfs.read(__dirname + '/../closure/numberSymbolsExt.js', 'b')
+            .then(function(content) {
+              numberSymbols += content;
+              return closureI18nExtractor.extractNumberSymbols(numberSymbols, localeInfo, currencySymbols);
+            });
         });
       });
 
