@@ -10,7 +10,7 @@ set -xe
 # Define reasonable set of browsers in case we are running manually from commandline
 if [[ -z "$BROWSERS" ]]
 then
-  BROWSERS="Chrome,Firefox,Opera,/Users/jenkins/bin/safari.sh,/Users/jenkins/bin/ie8.sh,/Users/jenkins/bin/ie9.sh"
+  BROWSERS="Chrome,Firefox,Opera,/Users/jenkins/bin/safari.sh"
 fi
 
 # CLEAN #
@@ -24,15 +24,15 @@ grunt ci-checks package --no-color
 
 mkdir -p test_out
 
-# DOCS generator unit tests #
-grunt test:docgen --no-color
-
 # UNIT TESTS #
 grunt test:unit --browsers $BROWSERS --reporters=dots,junit --no-colors --no-color
 
 # END TO END TESTS #
 grunt test:ci-protractor
 
+# DOCS APP TESTS #
+grunt test:docs --browsers $BROWSERS --reporters=dots,junit --no-colors --no-color
+
 # Promises/A+ TESTS #
 grunt test:promises-aplus --no-color
 
