@@ -1,4 +1,8 @@
-var isFunction = function isFunction(value){return typeof value == 'function';}
+/* global qFactory: false */
+'use strict';
+
+var isFunction = function isFunction(value){return typeof value == 'function';};
+var isPromiseLike = function isPromiseLike(obj) {return obj && isFunction(obj.then);};
 
 var $q = qFactory(process.nextTick, function noopExceptionHandler() {});
 
