@@ -4,7 +4,7 @@ var config = require('./protractor-shared-conf').config;
 
 config.specs = [
   'build/docs/ptore2e/**/*.js',
-  'docs/app/e2e/docsAppE2E.js'
+  'docs/app/e2e/**/*.scenario.js'
 ];
 
 config.capabilities = {
