@@ -5,7 +5,7 @@ exports.config = {
 
   specs: [
     'build/docs/ptore2e/**/*.js',
-    'docs/app/e2e/docsAppE2E.js'
+    'docs/app/e2e/*.scenario.js'
   ],
 
   capabilities: {
@@ -21,9 +21,9 @@ exports.config = {
 
     // Disable animations so e2e tests run more quickly
     var disableNgAnimate = function() {
-      angular.module('disableNgAnimate', []).run(function($animate) {
+      angular.module('disableNgAnimate', []).run(['$animate', function($animate) {
         $animate.enabled(false);
-      });
+      }]);
     };
 
     browser.addMockModule('disableNgAnimate', disableNgAnimate);
