@@ -71,6 +71,8 @@ function prepare {
     cd $TMP_DIR/bower-$repo
     replaceJsonProp "bower.json" "version" ".*" "$NEW_VERSION"
     replaceJsonProp "bower.json" "angular.*" ".*" "$NEW_VERSION"
+    replaceJsonProp "package.json" "version" ".*" "$NEW_VERSION"
+    replaceJsonProp "package.json" "angular.*" ".*" "$NEW_VERSION"
 
     git add -A
 
@@ -88,6 +90,24 @@ function publish {
     cd $TMP_DIR/bower-$repo
     git push origin master
     git push origin v$NEW_VERSION
+
+    # don't publish every build to npm
+    if [ "${NEW_VERSION/+sha}" = "$NEW_VERSION" ] ; then
+      if [ "${NEW_VERSION/-}" = "$NEW_VERSION" ] ; then
+        if [[ $NEW_VERSION =~ ^1\.2\.[0-9]+$ ]] ; then
+          # publish 1.2.x releases with the appropriate tag
+          # this ensures that `npm install` by default will not grab `1.2.x` releases
+          npm publish --tag=old
+        else
+          # publish releases as "latest"
+          npm publish
+        fi
+      else
+        # publish prerelease builds with the beta tag
+        npm publish --tag=beta
+      fi
+    fi
+
     cd $SCRIPT_DIR
   done
 }
