@@ -72,7 +72,8 @@ describe('ngClass', function() {
       $rootScope.$digest();
       expect(element.hasClass('A')).toBeFalsy();
       expect(element.hasClass('B')).toBeTruthy();
-  }));
+    })
+  );
 
 
   it('should support adding multiple classes via a space delimited string', inject(function($rootScope, $compile) {
@@ -152,6 +153,7 @@ describe('ngClass', function() {
     element.addClass('foo');
     $rootScope.dynCls = '';
     $rootScope.$digest();
+    expect(element[0].className).toBe('ng-scope');
   }));
 
 
@@ -159,6 +161,7 @@ describe('ngClass', function() {
     element = $compile('<div ng-class="dynCls"></div>')($rootScope);
     $rootScope.dynCls = [undefined, null];
     $rootScope.$digest();
+    expect(element[0].className).toBe('ng-scope');
   }));
 
 
@@ -192,6 +195,36 @@ describe('ngClass', function() {
   }));
 
 
+  it("should allow ngClassOdd/Even on the same element with overlapping classes", inject(function($rootScope, $compile, $animate) {
+    var className;
+
+    element = $compile('<ul><li ng-repeat="i in [0,1,2]" ng-class-odd="\'same odd\'" ng-class-even="\'same even\'"></li><ul>')($rootScope);
+    $rootScope.$digest();
+    var e1 = jqLite(element[0].childNodes[1]);
+    var e2 = jqLite(element[0].childNodes[5]);
+    expect(e1.hasClass('same')).toBeTruthy();
+    expect(e1.hasClass('odd')).toBeTruthy();
+    expect(e2.hasClass('same')).toBeTruthy();
+    expect(e2.hasClass('odd')).toBeTruthy();
+  }));
+
+  it('should allow ngClass with overlapping classes', inject(function($rootScope, $compile, $animate) {
+    element = $compile('<div ng-class="{\'same yes\': test, \'same no\': !test}"></div>')($rootScope);
+    $rootScope.$digest();
+
+    expect(element).toHaveClass('same');
+    expect(element).not.toHaveClass('yes');
+    expect(element).toHaveClass('no');
+
+    $rootScope.$apply(function() {
+      $rootScope.test = true;
+    });
+
+    expect(element).toHaveClass('same');
+    expect(element).toHaveClass('yes');
+    expect(element).not.toHaveClass('no');
+  }));
+
   it('should allow both ngClass and ngClassOdd/Even with multiple classes', inject(function($rootScope, $compile) {
     element = $compile('<ul>' +
       '<li ng-repeat="i in [0,1]" ng-class="[\'A\', \'B\']" ' +
@@ -261,6 +294,28 @@ describe('ngClass', function() {
   }));
 
 
+  it('should update ngClassOdd/Even when an item is added to the model', inject(function($rootScope, $compile) {
+    element = $compile('<ul>' +
+      '<li ng-repeat="i in items" ' +
+      'ng-class-odd="\'odd\'" ng-class-even="\'even\'">i</li>' +
+      '<ul>')($rootScope);
+    $rootScope.items = ['b','c','d'];
+    $rootScope.$digest();
+
+    $rootScope.items.unshift('a');
+    $rootScope.$digest();
+
+    var e1 = jqLite(element[0].childNodes[1]);
+    var e4 = jqLite(element[0].childNodes[7]);
+
+    expect(e1.hasClass('odd')).toBeTruthy();
+    expect(e1.hasClass('even')).toBeFalsy();
+
+    expect(e4.hasClass('even')).toBeTruthy();
+    expect(e4.hasClass('odd')).toBeFalsy();
+  }));
+
+
   it('should update ngClassOdd/Even when model is changed by filtering', inject(function($rootScope, $compile) {
     element = $compile('<ul>' +
       '<li ng-repeat="i in items track by $index" ' +
@@ -345,6 +400,7 @@ describe('ngClass animations', function() {
     //mocks are not used since the enter delegation method is called before addClass and
     //it makes it impossible to test to see that addClass is called first
     module('ngAnimate');
+    module('ngAnimateMock');
 
     var digestQueue = [];
     module(function($animateProvider) {
@@ -367,7 +423,7 @@ describe('ngClass animations', function() {
         };
       };
     });
-    inject(function($compile, $rootScope, $rootElement, $animate, $timeout, $document) {
+    inject(function($compile, $rootScope, $browser, $rootElement, $animate, $timeout, $document) {
 
       // Enable animations by triggering the first item in the postDigest queue
       digestQueue.shift()();
@@ -407,7 +463,7 @@ describe('ngClass animations', function() {
       //is spaced-out then it is required so that the original digestion
       //is kicked into gear
       $rootScope.$digest();
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       expect(element.data('state')).toBe('crazy-enter');
       expect(enterComplete).toBe(true);
