@@ -112,7 +112,7 @@ describe('ngInclude', function() {
   it('should fire $includeContentRequested event on scope after making the xhr call', inject(
       function ($rootScope, $compile, $httpBackend) {
     var contentRequestedSpy = jasmine.createSpy('content requested').andCallFake(function (event) {
-        expect(event.targetScope).toBe($rootScope);
+      expect(event.targetScope).toBe($rootScope);
     });
 
     $httpBackend.whenGET('url').respond('my partial');
@@ -233,7 +233,8 @@ describe('ngInclude', function() {
     var called = 0;
     // we want to assert only during first watch
     $rootScope.$watch(function() {
-      if (!called++) expect(element.text()).toBe('');
+      if (!called) expect(element.text()).toBe('');
+      called++;
     });
 
     $rootScope.$digest();
@@ -249,7 +250,7 @@ describe('ngInclude', function() {
     $rootScope.templateUrl = 'myUrl1';
     $rootScope.logger = function(msg) {
       log[msg] = true;
-    }
+    };
     $compile(element)($rootScope);
     expect(log).toEqual({});
 
@@ -368,7 +369,7 @@ describe('ngInclude', function() {
 
       expect(autoScrollSpy).not.toHaveBeenCalled();
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       expect(autoScrollSpy).toHaveBeenCalledOnce();
     }));
@@ -385,7 +386,7 @@ describe('ngInclude', function() {
       });
 
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       $rootScope.$apply(function () {
         $rootScope.tpl = 'another.html';
@@ -394,7 +395,7 @@ describe('ngInclude', function() {
 
       expect($animate.queue.shift().event).toBe('leave');
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       $rootScope.$apply(function() {
         $rootScope.tpl = 'template.html';
@@ -403,7 +404,7 @@ describe('ngInclude', function() {
 
       expect($animate.queue.shift().event).toBe('leave');
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       expect(autoScrollSpy).toHaveBeenCalled();
       expect(autoScrollSpy.callCount).toBe(3);
@@ -419,7 +420,7 @@ describe('ngInclude', function() {
       });
 
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
       expect(autoScrollSpy).not.toHaveBeenCalled();
     }));
 
@@ -435,7 +436,7 @@ describe('ngInclude', function() {
       });
 
       expect($animate.queue.shift().event).toBe('enter');
-      $timeout.flush();
+      $animate.triggerCallbacks();
 
       $rootScope.$apply(function () {
         $rootScope.tpl = 'template.html';
@@ -451,16 +452,17 @@ describe('ngInclude', function() {
     }));
 
     it('should only call $anchorScroll after the "enter" animation completes', inject(
-        compileAndLink('<div><ng:include src="tpl" autoscroll></ng:include></div>'),
-        function($rootScope, $animate, $timeout) {
-          expect(autoScrollSpy).not.toHaveBeenCalled();
+      compileAndLink('<div><ng:include src="tpl" autoscroll></ng:include></div>'),
+      function($rootScope, $animate, $timeout) {
+        expect(autoScrollSpy).not.toHaveBeenCalled();
 
-          $rootScope.$apply("tpl = 'template.html'");
-          expect($animate.queue.shift().event).toBe('enter');
-          $timeout.flush();
+        $rootScope.$apply("tpl = 'template.html'");
+        expect($animate.queue.shift().event).toBe('enter');
+        $animate.triggerCallbacks();
 
-          expect(autoScrollSpy).toHaveBeenCalledOnce();
-    }));
+        expect(autoScrollSpy).toHaveBeenCalledOnce();
+      }
+    ));
   });
 });
 
@@ -504,7 +506,7 @@ describe('ngInclude and transcludes', function() {
     });
   });
 
-  it("should compile it's content correctly (although we remove it later)", function() {
+  it("should compile its content correctly (although we remove it later)", function() {
     var testElement;
     module(function() {
       directive('test', function() {
@@ -569,8 +571,8 @@ describe('ngInclude and transcludes', function() {
 describe('ngInclude animations', function() {
   var body, element, $rootElement;
 
-  function html(html) {
-    $rootElement.html(html);
+  function html(content) {
+    $rootElement.html(content);
     element = $rootElement.children().eq(0);
     return element;
   }
@@ -611,7 +613,8 @@ describe('ngInclude animations', function() {
       var animation = $animate.queue.pop();
       expect(animation.event).toBe('enter');
       expect(animation.element.text()).toBe('data');
-  }));
+    })
+  );
 
   it('should fire off the leave animation',
     inject(function($compile, $rootScope, $templateCache, $animate) {
@@ -635,7 +638,8 @@ describe('ngInclude animations', function() {
       animation = $animate.queue.shift();
       expect(animation.event).toBe('leave');
       expect(animation.element.text()).toBe('data');
-  }));
+    })
+  );
 
   it('should animate two separate ngInclude elements',
     inject(function($compile, $rootScope, $templateCache, $animate) {
@@ -661,6 +665,47 @@ describe('ngInclude animations', function() {
       expect(itemA.attr('ng-include')).toBe('tpl');
       expect(itemB.attr('ng-include')).toBe('tpl');
       expect(itemA).not.toEqual(itemB);
-  }));
+    }
+  ));
 
+  it('should destroy the previous leave animation if a new one takes place', function() {
+    module(function($provide) {
+      $provide.value('$animate', {
+        enabled : function() { return true; },
+        leave : function() {
+          //DOM operation left blank
+        },
+        enter : function(element, parent, after) {
+          angular.element(after).after(element);
+        }
+      });
+    });
+    inject(function ($compile, $rootScope, $animate, $templateCache) {
+      var item;
+      var $scope = $rootScope.$new();
+      element = $compile(html(
+        '<div>' +
+          '<div ng-include="inc">Yo</div>' +
+        '</div>'
+      ))($scope);
+
+      $templateCache.put('one', [200, '<div>one</div>', {}]);
+      $templateCache.put('two', [200, '<div>two</div>', {}]);
+
+      $scope.$apply('inc = "one"');
+
+      var destroyed, inner = element.children(0);
+      inner.on('$destroy', function() {
+        destroyed = true;
+      });
+
+      $scope.$apply('inc = "two"');
+
+      $scope.$apply('inc = "one"');
+
+      $scope.$apply('inc = "two"');
+
+      expect(destroyed).toBe(true);
+    });
+  });
 });
