@@ -1,3 +1,6 @@
+/* global createHttpBackend: false, createMockXhr: false, MockXhr: false */
+'use strict';
+
 describe('$httpBackend', function() {
 
   var $backend, $browser, callbacks,
@@ -39,7 +42,19 @@ describe('$httpBackend', function() {
     fakeDocument = {
       $$scripts: [],
       createElement: jasmine.createSpy('createElement').andCallFake(function() {
-        return {};
+        // msie8 depends on modifying readyState for testing. This property is readonly,
+        // so it requires a fake object. For other browsers, we do need to make use of
+        // event listener registration/deregistration, so these stubs are needed.
+        if (msie <= 8) {
+          return {
+            attachEvent: noop,
+            detachEvent: noop,
+            addEventListener: noop,
+            removeEventListener: noop
+          };
+        }
+        // Return a proper script element...
+        return document.createElement(arguments[0]);
       }),
       body: {
         appendChild: jasmine.createSpy('body.appendChild').andCallFake(function(script) {
@@ -88,6 +103,25 @@ describe('$httpBackend', function() {
     expect(callback).toHaveBeenCalledOnce();
   });
 
+  it('should not touch xhr.statusText when request is aborted on IE9 or lower', function() {
+    callback.andCallFake(function(status, response, headers, statusText) {
+      expect(statusText).toBe((!msie || msie >= 10) ? 'OK' : '');
+    });
+
+    $backend('GET', '/url', null, callback, {}, 2000);
+    xhr = MockXhr.$$lastInstance;
+    spyOn(xhr, 'abort');
+
+    fakeTimeout.flush();
+    expect(xhr.abort).toHaveBeenCalledOnce();
+
+    xhr.status = 0;
+    xhr.readyState = 4;
+    xhr.statusText = 'OK';
+    xhr.onreadystatechange();
+    expect(callback).toHaveBeenCalledOnce();
+  });
+
   it('should call completion function with empty string if not present', function() {
     callback.andCallFake(function(status, response, headers, statusText) {
       expect(statusText).toBe('');
@@ -278,7 +312,7 @@ describe('$httpBackend', function() {
       expect(response).toBe('response');
     });
 
-    $backend = createHttpBackend($browser, function() { return new SyncXhr() });
+    $backend = createHttpBackend($browser, function() { return new SyncXhr(); });
     $backend('GET', '/url', null, callback);
     expect(callback).toHaveBeenCalledOnce();
   });
@@ -356,7 +390,7 @@ describe('$httpBackend', function() {
         script.readyState = 'complete';
         script.onreadystatechange();
       } else {
-        script.onload();
+        browserTrigger(script, "load");
       }
 
       expect(callback).toHaveBeenCalledOnce();
@@ -372,12 +406,11 @@ describe('$httpBackend', function() {
           callbackId = script.src.match(SCRIPT_URL)[2];
 
       callbacks[callbackId]('some-data');
-
       if (script.onreadystatechange) {
         script.readyState = 'complete';
         script.onreadystatechange();
       } else {
-        script.onload();
+        browserTrigger(script, "load");
       }
 
       expect(callbacks[callbackId]).toBe(angular.noop);
@@ -385,7 +418,7 @@ describe('$httpBackend', function() {
     });
 
 
-    if(msie<=8) {
+    if (msie <= 8) {
 
       it('should attach onreadystatechange handler to the script object', function() {
         $backend('JSONP', 'http://example.org/path?cb=JSON_CALLBACK', null, noop);
@@ -400,42 +433,9 @@ describe('$httpBackend', function() {
         expect(script.onreadystatechange).toBe(null);
       });
 
-    } else {
-
-      it('should attach onload and onerror handlers to the script object', function() {
-        $backend('JSONP', 'http://example.org/path?cb=JSON_CALLBACK', null, noop);
-
-        expect(fakeDocument.$$scripts[0].onload).toEqual(jasmine.any(Function));
-        expect(fakeDocument.$$scripts[0].onerror).toEqual(jasmine.any(Function));
-
-        var script = fakeDocument.$$scripts[0];
-        script.onload();
-
-        expect(script.onload).toBe(null);
-        expect(script.onerror).toBe(null);
-      });
 
     }
 
-    it('should call callback with status -2 when script fails to load', function() {
-      callback.andCallFake(function(status, response) {
-        expect(status).toBe(-2);
-        expect(response).toBeUndefined();
-      });
-
-      $backend('JSONP', 'http://example.org/path?cb=JSON_CALLBACK', null, callback);
-      expect(fakeDocument.$$scripts.length).toBe(1);
-
-      var script = fakeDocument.$$scripts.shift();
-      if (script.onreadystatechange) {
-        script.readyState = 'complete';
-        script.onreadystatechange();
-      } else {
-        script.onload();
-      }
-      expect(callback).toHaveBeenCalledOnce();
-    });
-
 
     it('should set url to current location if not specified or empty string', function() {
       $backend('JSONP', undefined, null, callback);
@@ -523,6 +523,7 @@ describe('$httpBackend', function() {
     });
 
     it('should convert 0 to 404 if no content - relative url', function() {
+      /* global urlParsingNode: true */
       var originalUrlParsingNode = urlParsingNode;
 
       //temporarily overriding the DOM element to pretend that the test runs origin with file:// protocol
