@@ -985,6 +985,18 @@ describe('$http', function() {
       });
 
 
+      it('should have patch()', function() {
+        $httpBackend.expect('PATCH', '/url', 'some-data').respond('');
+        $http.patch('/url', 'some-data');
+      });
+
+
+      it('patch() should allow config param', function() {
+        $httpBackend.expect('PATCH', '/url', 'some-data', checkHeader('Custom', 'Header')).respond('');
+        $http.patch('/url', 'some-data', {headers: {'Custom': 'Header'}});
+      });
+
+
       it('should have jsonp()', function() {
         $httpBackend.expect('JSONP', '/url').respond('');
         $http.jsonp('/url');
@@ -1041,6 +1053,12 @@ describe('$http', function() {
           });
 
 
+          it('should transform object with date into json', function() {
+            $httpBackend.expect('POST', '/url', {"date": new Date(Date.UTC(2013, 11, 25))}).respond('');
+            $http({method: 'POST', url: '/url', data: {date: new Date(Date.UTC(2013, 11, 25))}});
+          });
+
+
           it('should ignore strings', function() {
             $httpBackend.expect('POST', '/url', 'string-data').respond('');
             $http({method: 'POST', url: '/url', data: 'string-data'});
