@@ -93,6 +93,11 @@ describe('$location', function() {
       expect(url.absUrl()).toBe('http://www.domain.com:9877/1?search=a&b=c&d#hash');
     });
 
+    it('path() should allow using 0 as path', function() {
+      url.path(0);
+      expect(url.path()).toBe('/0');
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/0?search=a&b=c&d#hash');
+    });
 
     it('path() should set to empty path on null value', function () {
       url.path('/foo');
@@ -191,6 +196,11 @@ describe('$location', function() {
       expect(url.absUrl()).toBe('http://www.domain.com:9877/path/b?search=a&b=c&d#5');
     });
 
+    it('hash() should allow using 0', function() {
+      url.hash(0);
+      expect(url.hash()).toBe('0');
+      expect(url.absUrl()).toBe('http://www.domain.com:9877/path/b?search=a&b=c&d#0');
+    });
 
     it('hash() should accept null parameter', function() {
       url.hash(null);
@@ -291,9 +301,9 @@ describe('$location', function() {
     });
 
     it('should not rewrite when hashbang url is not given', function() {
-      initService(true, '!', true);
+      initService({html5Mode:true,hashPrefix: '!',supportHistory: true});
       inject(
-        initBrowser('http://domain.com/base/a/b', '/base'),
+        initBrowser({url:'http://domain.com/base/a/b',basePath: '/base'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/a/b');
         }
@@ -526,24 +536,24 @@ describe('$location', function() {
   });
 
 
-  function initService(html5Mode, hashPrefix, supportHistory) {
+  function initService(options) {
     return module(function($provide, $locationProvider){
-      $locationProvider.html5Mode(html5Mode);
-      $locationProvider.hashPrefix(hashPrefix);
-      $provide.value('$sniffer', {history: supportHistory});
+      $locationProvider.html5Mode(options.html5Mode);
+      $locationProvider.hashPrefix(options.hashPrefix);
+      $provide.value('$sniffer', {history: options.supportHistory});
     });
   }
-  function initBrowser(url, basePath) {
+  function initBrowser(options) {
     return function($browser){
-      $browser.url(url);
-      $browser.$$baseHref = basePath;
+      $browser.url(options.url);
+      $browser.$$baseHref = options.basePath;
     };
   }
 
   describe('wiring', function() {
 
-    beforeEach(initService(false, '!', true));
-    beforeEach(inject(initBrowser('http://new.com/a/b#!', 'http://new.com/a/b')));
+    beforeEach(initService({html5Mode:false,hashPrefix: '!',supportHistory: true}));
+    beforeEach(inject(initBrowser({url:'http://new.com/a/b#!',basePath: 'http://new.com/a/b'})));
 
 
     it('should update $location when browser url changes', inject(function($browser, $location) {
@@ -667,9 +677,9 @@ describe('$location', function() {
   describe('disabled history', function() {
 
     it('should use hashbang url with hash prefix', function() {
-      initService(false, '!');
+      initService({html5Mode:false,hashPrefix: '!'});
       inject(
-        initBrowser('http://domain.com/base/index.html#!/a/b', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html#!/a/b',basePath: '/base/index.html'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/index.html#!/a/b');
           $location.path('/new');
@@ -682,9 +692,9 @@ describe('$location', function() {
 
 
     it('should use hashbang url without hash prefix', function() {
-      initService(false, '');
+      initService({html5Mode:false,hashPrefix: ''});
       inject(
-        initBrowser('http://domain.com/base/index.html#/a/b', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html#/a/b',basePath: '/base/index.html'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/index.html#/a/b');
           $location.path('/new');
@@ -705,9 +715,9 @@ describe('$location', function() {
     }));
 
     it('should use hashbang url with hash prefix', function() {
-      initService(true, '!!', false);
+      initService({html5Mode:true,hashPrefix: '!!',supportHistory: false});
       inject(
-        initBrowser('http://domain.com/base/index.html#!!/a/b', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html#!!/a/b',basePath: '/base/index.html'}),
         function($rootScope, $location,  $browser) {
           expect($browser.url()).toBe('http://domain.com/base/index.html#!!/a/b');
           $location.path('/new');
@@ -720,9 +730,9 @@ describe('$location', function() {
 
 
     it('should redirect to hashbang url when new url given', function() {
-      initService(true, '!');
+      initService({html5Mode:true,hashPrefix: '!'});
       inject(
-        initBrowser('http://domain.com/base/new-path/index.html', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/new-path/index.html',basePath: '/base/index.html'}),
         function($browser, $location) {
           expect($browser.url()).toBe('http://domain.com/base/index.html#!/new-path/index.html');
         }
@@ -730,9 +740,9 @@ describe('$location', function() {
     });
 
     it('should correctly convert html5 url with path matching basepath to hashbang url', function () {
-      initService(true, '!', false);
+      initService({html5Mode:true,hashPrefix: '!',supportHistory: false});
       inject(
-        initBrowser('http://domain.com/base/index.html', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html',basePath: '/base/index.html'}),
         function($browser, $location) {
           expect($browser.url()).toBe('http://domain.com/base/index.html#!/index.html');
         }
@@ -749,9 +759,9 @@ describe('$location', function() {
     }));
 
     it('should use new url', function() {
-      initService(true, '', true);
+      initService({html5Mode:true,hashPrefix: '',supportHistory: true});
       inject(
-        initBrowser('http://domain.com/base/old/index.html#a', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/old/index.html#a',basePath: '/base/index.html'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/old/index.html#a');
           $location.path('/new');
@@ -764,9 +774,9 @@ describe('$location', function() {
 
 
     it('should rewrite when hashbang url given', function() {
-      initService(true, '!', true);
+      initService({html5Mode:true,hashPrefix: '!',supportHistory: true});
       inject(
-        initBrowser('http://domain.com/base/index.html#!/a/b', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html#!/a/b',basePath: '/base/index.html'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/a/b');
           $location.path('/new');
@@ -780,9 +790,9 @@ describe('$location', function() {
 
 
     it('should rewrite when hashbang url given (without hash prefix)', function() {
-      initService(true, '', true);
+      initService({html5Mode:true,hashPrefix: '',supportHistory: true});
       inject(
-        initBrowser('http://domain.com/base/index.html#/a/b', '/base/index.html'),
+        initBrowser({url:'http://domain.com/base/index.html#/a/b',basePath: '/base/index.html'}),
         function($rootScope, $location, $browser) {
           expect($browser.url()).toBe('http://domain.com/base/a/b');
           expect($location.path()).toBe('/a/b');
@@ -792,9 +802,9 @@ describe('$location', function() {
 
 
     it('should set appBase to serverBase if base[href] is missing', function() {
-      initService(true, '!', true);
+      initService({html5Mode:true,hashPrefix: '!',supportHistory: true});
       inject(
-          initBrowser('http://domain.com/my/view1#anchor1', ''),
+          initBrowser({url:'http://domain.com/my/view1#anchor1',basePath: ''}),
           function($rootScope, $location, $browser) {
             expect($browser.url()).toBe('http://domain.com/my/view1#anchor1');
             expect($location.path()).toBe('/my/view1');
@@ -837,21 +847,23 @@ describe('$location', function() {
 
     var root, link, originalBrowser, lastEventPreventDefault;
 
-    function configureService(linkHref, html5Mode, supportHist, relLink, attrs, content) {
-      if (typeof relLink !== "boolean") {
-        content = attrs;
-        attrs = relLink;
-        relLink = false;
-      }
+    function configureService(options) {
+      var linkHref = options.linkHref,
+          html5Mode = options.html5Mode,
+          supportHist = options.supportHist,
+          relLink = options.relLink,
+          attrs = options.attrs,
+          content = options.content;
+
       module(function($provide, $locationProvider) {
         attrs = attrs ? ' ' + attrs + ' ' : '';
 
-        // fake the base behavior
         if (typeof linkHref === 'string') {
           if (!relLink) {
             if (linkHref[0] == '/') {
               linkHref = 'http://host.com' + linkHref;
             } else if(!linkHref.match(/:\/\//)) {
+              // fake the behavior of <base> tag
               linkHref = 'http://host.com/base/' + linkHref;
             }
           }
@@ -876,8 +888,8 @@ describe('$location', function() {
     }
 
     function initBrowser() {
-      return function($browser){
-        $browser.url('http://host.com/base');
+      return function($browser, $document){
+        $browser.url('http://host.com/base/index.html');
         $browser.$$baseHref = '/base/index.html';
       };
     }
@@ -911,7 +923,7 @@ describe('$location', function() {
 
 
     it('should rewrite rel link to new url when history enabled on new browser', function() {
-      configureService('link?a#b', true, true);
+      configureService({linkHref: 'link?a#b', html5Mode: true, supportHist: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -924,7 +936,7 @@ describe('$location', function() {
 
 
     it('should do nothing if already on the same URL', function() {
-      configureService('/base/', true, true);
+      configureService({linkHref: '/base/', html5Mode: true, supportHist: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -951,7 +963,7 @@ describe('$location', function() {
 
 
     it('should rewrite abs link to new url when history enabled on new browser', function() {
-      configureService('/base/link?a#b', true, true);
+      configureService({linkHref: '/base/link?a#b', html5Mode: true, supportHist: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -964,7 +976,7 @@ describe('$location', function() {
 
 
     it('should rewrite rel link to hashbang url when history enabled on old browser', function() {
-      configureService('link?a#b', true, false);
+      configureService({linkHref: 'link?a#b', html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -978,7 +990,7 @@ describe('$location', function() {
 
     // Regression (gh-7721)
     it('should not throw when clicking anchor with no href attribute when history enabled on old browser', function() {
-      configureService(null, true, false);
+      configureService({linkHref: null, html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -991,12 +1003,14 @@ describe('$location', function() {
 
 
     it('should produce relative paths correctly when $location.path() is "/" when history enabled on old browser', function() {
-      configureService('partial1', true, false, true);
+      configureService({linkHref: 'partial1', html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
-        function($browser, $location) {
-          $location.path('/');
+        function($browser, $location, $rootScope) {
+          $rootScope.$apply(function() {
+            $location.path('/');
+          });
           browserTrigger(link, 'click');
           expectRewriteTo($browser, 'http://host.com/base/index.html#!/partial1');
         }
@@ -1005,7 +1019,7 @@ describe('$location', function() {
 
 
     it('should rewrite abs link to hashbang url when history enabled on old browser', function() {
-      configureService('/base/link?a#b', true, false);
+      configureService({linkHref: '/base/link?a#b', html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -1018,7 +1032,7 @@ describe('$location', function() {
 
 
     it('should not rewrite full url links do different domain', function() {
-      configureService('http://www.dot.abc/a?b=c', true);
+      configureService({linkHref: 'http://www.dot.abc/a?b=c', html5Mode: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1031,7 +1045,7 @@ describe('$location', function() {
 
 
     it('should not rewrite links with target="_blank"', function() {
-      configureService('/a?b=c', true, true, 'target="_blank"');
+      configureService({linkHref: '/a?b=c', html5Mode: true, supportHist: true, attrs: 'target="_blank"'});
       inject(
         initBrowser(),
         initLocation(),
@@ -1044,7 +1058,7 @@ describe('$location', function() {
 
 
     it('should not rewrite links with target specified', function() {
-      configureService('/a?b=c', true, true, 'target="some-frame"');
+      configureService({linkHref: '/a?b=c', html5Mode: true, supportHist: true, attrs: 'target="some-frame"'});
       inject(
         initBrowser(),
         initLocation(),
@@ -1057,7 +1071,7 @@ describe('$location', function() {
 
 
     it('should not rewrite links with `javascript:` URI', function() {
-      configureService(' jAvAsCrIpT:throw new Error("Boom!")', true, true, true);
+      configureService({linkHref: ' jAvAsCrIpT:throw new Error("Boom!")', html5Mode: true, supportHist: true, relLink: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1070,7 +1084,7 @@ describe('$location', function() {
 
 
     it('should not rewrite links with `mailto:` URI', function() {
-      configureService(' mAiLtO:foo@bar.com', true, true, true);
+      configureService({linkHref: ' mAiLtO:foo@bar.com', html5Mode: true, supportHist: true, relLink: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1083,7 +1097,7 @@ describe('$location', function() {
 
 
     it('should rewrite full url links to same domain and base path', function() {
-      configureService('http://host.com/base/new', true);
+      configureService({linkHref: 'http://host.com/base/new', html5Mode: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1096,7 +1110,7 @@ describe('$location', function() {
 
 
     it('should rewrite when clicked span inside link', function() {
-      configureService('some/link', true, true, '', '<span>link</span>');
+      configureService({linkHref: 'some/link', html5Mode: true, supportHist: true, attrs: '', content: '<span>link</span>'});
       inject(
         initBrowser(),
         initLocation(),
@@ -1112,7 +1126,7 @@ describe('$location', function() {
 
     it('should not rewrite when link to different base path when history enabled on new browser',
         function() {
-      configureService('/other_base/link', true, true);
+      configureService({linkHref: '/other_base/link', html5Mode: true, supportHist: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1126,7 +1140,7 @@ describe('$location', function() {
 
     it('should not rewrite when link to different base path when history enabled on old browser',
         function() {
-      configureService('/other_base/link', true, false);
+      configureService({linkHref: '/other_base/link', html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -1139,7 +1153,7 @@ describe('$location', function() {
 
 
     it('should not rewrite when link to different base path when history disabled', function() {
-      configureService('/other_base/link', false);
+      configureService({linkHref: '/other_base/link', html5Mode: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -1153,7 +1167,7 @@ describe('$location', function() {
 
     it('should not rewrite when full link to different base path when history enabled on new browser',
         function() {
-      configureService('http://host.com/other_base/link', true, true);
+      configureService({linkHref: 'http://host.com/other_base/link', html5Mode: true, supportHist: true});
       inject(
         initBrowser(),
         initLocation(),
@@ -1167,7 +1181,7 @@ describe('$location', function() {
 
     it('should not rewrite when full link to different base path when history enabled on old browser',
         function() {
-      configureService('http://host.com/other_base/link', true, false);
+      configureService({linkHref: 'http://host.com/other_base/link', html5Mode: true, supportHist: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -1180,7 +1194,7 @@ describe('$location', function() {
 
 
     it('should not rewrite when full link to different base path when history disabled', function() {
-      configureService('http://host.com/other_base/link', false);
+      configureService({linkHref: 'http://host.com/other_base/link', html5Mode: false});
       inject(
         initBrowser(),
         initLocation(),
@@ -1191,62 +1205,32 @@ describe('$location', function() {
       );
     });
 
-
-    it('should rewrite relative links relative to current path when history disabled', function() {
-      configureService('link', true, false, true);
-      inject(
-        initBrowser(),
-        initLocation(),
-        function($browser, $location) {
-          $location.path('/some');
-          browserTrigger(link, 'click');
-          expectRewriteTo($browser, 'http://host.com/base/index.html#!/some/link');
-        }
-      );
-    });
-
-
-    it('should replace current path when link begins with "/" and history disabled', function() {
-      configureService('/link', true, false, true);
-      inject(
-        initBrowser(),
-        initLocation(),
-        function($browser, $location) {
-          $location.path('/some');
-          browserTrigger(link, 'click');
-          expectRewriteTo($browser, 'http://host.com/base/index.html#!/link');
-        }
-      );
-    });
-
-
     it('should replace current hash fragment when link begins with "#" history disabled', function() {
-      configureService('#link', true, false, true);
+      configureService({linkHref: '#link', html5Mode: true, supportHist: false, relLink: false});
       inject(
         initBrowser(),
         initLocation(),
-        function($browser, $location) {
-          // Initialize browser URL
-          $location.path('/some');
-          $location.hash('foo');
+        function($browser, $location, $rootScope) {
+          $rootScope.$apply(function() {
+            $location.hash('foo');
+          });
           browserTrigger(link, 'click');
           expect($location.hash()).toBe('link');
-          expectRewriteTo($browser, 'http://host.com/base/index.html#!/some#link');
+          expectRewriteTo($browser, 'http://host.com/base/index.html#!#link');
         }
       );
     });
 
-
     // don't run next tests on IE<9, as browserTrigger does not simulate pressed keys
     if (!msie || msie >= 9) {
 
       it('should not rewrite when clicked with ctrl pressed', function() {
-        configureService('/a?b=c', true, true);
+        configureService({linkHref: '/a?b=c', html5Mode: true, supportHist: true});
         inject(
           initBrowser(),
           initLocation(),
           function($browser) {
-            browserTrigger(link, 'click', ['ctrl']);
+            browserTrigger(link, 'click', { keys: ['ctrl'] });
             expectNoRewrite($browser);
           }
         );
@@ -1254,12 +1238,12 @@ describe('$location', function() {
 
 
       it('should not rewrite when clicked with meta pressed', function() {
-        configureService('/a?b=c', true, true);
+        configureService({linkHref: '/a?b=c', html5Mode: true, supportHist: true});
         inject(
           initBrowser(),
           initLocation(),
           function($browser) {
-            browserTrigger(link, 'click', ['meta']);
+            browserTrigger(link, 'click', { keys: ['meta'] });
             expectNoRewrite($browser);
           }
         );
@@ -1348,7 +1332,8 @@ describe('$location', function() {
 
         var event = {
           target: jqLite(window.document.body).find('a')[0],
-          preventDefault: jasmine.createSpy('preventDefault')
+          preventDefault: jasmine.createSpy('preventDefault'),
+          isDefaultPrevented: jasmine.createSpy().andReturn(false)
         };
 
 
@@ -1378,7 +1363,8 @@ describe('$location', function() {
 
         var event = {
           target: jqLite(window.document.body).find('a')[0],
-          preventDefault: jasmine.createSpy('preventDefault')
+          preventDefault: jasmine.createSpy('preventDefault'),
+          isDefaultPrevented: jasmine.createSpy().andReturn(false)
         };
 
 
@@ -1543,8 +1529,12 @@ describe('$location', function() {
 
 
     it('should listen on click events on href and prevent browser default in html5 mode', function() {
-      module(function($locationProvider) {
+      module(function($locationProvider, $provide) {
         $locationProvider.html5Mode(true);
+        $provide.decorator('$browser', function($delegate) {
+          $delegate.$$baseHref = '/';
+          return $delegate;
+        });
         return function($rootElement, $compile, $rootScope) {
           $rootElement.html('<a href="http://server/somePath">link</a>');
           $compile($rootElement)($rootScope);
@@ -1601,6 +1591,13 @@ describe('$location', function() {
     );
   });
 
+  function parseLinkAndReturn(location, url, relHref) {
+    if (location.$$parseLinkUrl(url, relHref)) {
+      return location.absUrl();
+    }
+    return undefined;
+  }
+
   describe('LocationHtml5Url', function() {
     var location, locationIndex;
 
@@ -1610,13 +1607,14 @@ describe('$location', function() {
     });
 
     it('should rewrite URL', function() {
-      expect(location.$$rewrite('http://other')).toEqual(undefined);
-      expect(location.$$rewrite('http://server/pre')).toEqual('http://server/pre/');
-      expect(location.$$rewrite('http://server/pre/')).toEqual('http://server/pre/');
-      expect(location.$$rewrite('http://server/pre/otherPath')).toEqual('http://server/pre/otherPath');
-      expect(locationIndex.$$rewrite('http://server/pre')).toEqual('http://server/pre/');
-      expect(locationIndex.$$rewrite('http://server/pre/')).toEqual('http://server/pre/');
-      expect(locationIndex.$$rewrite('http://server/pre/otherPath')).toEqual('http://server/pre/otherPath');
+      expect(parseLinkAndReturn(location, 'http://other')).toEqual(undefined);
+      expect(parseLinkAndReturn(location, 'http://server/pre')).toEqual('http://server/pre/');
+      expect(parseLinkAndReturn(location, 'http://server/pre/')).toEqual('http://server/pre/');
+      expect(parseLinkAndReturn(location, 'http://server/pre/otherPath')).toEqual('http://server/pre/otherPath');
+
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre')).toEqual('http://server/pre/');
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre/')).toEqual('http://server/pre/');
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre/otherPath')).toEqual('http://server/pre/otherPath');
     });
   });
 
@@ -1624,14 +1622,21 @@ describe('$location', function() {
   describe('LocationHashbangUrl', function() {
     var location;
 
+    function parseLinkAndReturn(location, url, relHref) {
+      if (location.$$parseLinkUrl(url, relHref)) {
+        return location.absUrl();
+      }
+      return undefined;
+    }
+
     it('should rewrite URL', function() {
       /* jshint scripturl: true */
       location = new LocationHashbangUrl('http://server/pre/', '#');
 
-      expect(location.$$rewrite('http://other')).toEqual(undefined);
-      expect(location.$$rewrite('http://server/pre/')).toEqual('http://server/pre/');
-      expect(location.$$rewrite('http://server/pre/#otherPath')).toEqual('http://server/pre/#otherPath');
-      expect(location.$$rewrite('javascript:void(0)')).toEqual(undefined);
+      expect(parseLinkAndReturn(location, 'http://other')).toEqual(undefined);
+      expect(parseLinkAndReturn(location, 'http://server/pre/')).toEqual('http://server/pre/');
+      expect(parseLinkAndReturn(location, 'http://server/pre/#otherPath')).toEqual('http://server/pre/#/otherPath');
+      expect(parseLinkAndReturn(location, 'javascript:void(0)')).toEqual(undefined);
     });
 
     it("should not set hash if one was not originally specified", function() {
@@ -1681,13 +1686,14 @@ describe('$location', function() {
     });
 
     it('should rewrite URL', function() {
-      expect(location.$$rewrite('http://other')).toEqual(undefined);
-      expect(location.$$rewrite('http://server/pre')).toEqual('http://server/pre/');
-      expect(location.$$rewrite('http://server/pre/')).toEqual('http://server/pre/');
-      expect(location.$$rewrite('http://server/pre/otherPath')).toEqual('http://server/pre/#!otherPath');
-      expect(locationIndex.$$rewrite('http://server/pre')).toEqual('http://server/pre/');
-      expect(locationIndex.$$rewrite('http://server/pre/')).toEqual(undefined);
-      expect(locationIndex.$$rewrite('http://server/pre/otherPath')).toEqual('http://server/pre/index.html#!otherPath');
+      expect(parseLinkAndReturn(location, 'http://other')).toEqual(undefined);
+      expect(parseLinkAndReturn(location, 'http://server/pre')).toEqual('http://server/pre/#!');
+      expect(parseLinkAndReturn(location, 'http://server/pre/')).toEqual('http://server/pre/#!');
+      expect(parseLinkAndReturn(location, 'http://server/pre/otherPath')).toEqual('http://server/pre/#!/otherPath');
+
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre')).toEqual('http://server/pre/index.html#!');
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre/')).toEqual(undefined);
+      expect(parseLinkAndReturn(locationIndex, 'http://server/pre/otherPath')).toEqual('http://server/pre/index.html#!/otherPath');
     });
   });
 });
